<?php
/**
 * @author  wassim jied August 2016
 * @email   jiwassim@gmail.com 
 * @url     coderspirit.blogspot.com
 * @license GNU/GPL
*/

defined('_JEXEC') or die('Restricted Access');

require_once dirname(__FILE__).DS.'..'.DS.'models'.DS.'JqckCaptchaModel.php';

class JqckFieldsService {

	/**
	* Validate a field from a post or get
	* @param $requestName input name
	* @pram $xmlSpec XML specification of the input based on XmlEngine spec
	* @pram $sid the session ID associated to the jqck captcha
	* @return error message or null if no error detected
	**/
	public static function validateField($requestName,$xmlSpec,$sid){
		//No controle for displayed fields
		if($xmlSpec->type == "DISPLAY")return 0;
		//Raw and text
		elseif($xmlSpec->type == "TEXT" || $xmlSpec->type == "RAW") return JqckFieldsService::validateTextField($requestName,$xmlSpec);                
		elseif($xmlSpec->type == "EMAIL") return JqckFieldsService::validateEmail($requestName,$xmlSpec);
        elseif($xmlSpec->type == "NUMERIC") return JqckFieldsService::validateNumricField($requestName,$xmlSpec);
		
	}
	/**
	* Validate a text/raw field
	* @param $requestName input name
	* @param $xmlSpec XML specification of the input based on XmlEngine spec
	* @return error message or null if no error detected
	**/
	private static function validateTextField($requestName,$xmlSpec){
		$data = JRequest::getVar($requestName);
		if(strlen($data)<$xmlSpec->min || strlen($data)>$xmlSpec->max)
			return JText::sprintf( 'FIELD_CONSTRAINT_SIZE', $xmlSpec->label, $xmlSpec->min, $xmlSpec->max );
		return null;
	
	}
	/**
	* Validate an email field
	* @param $requestName input name
	* @param $xmlSpec XML specification of the input based on XmlEngine spec
	* @return error message or null if no error detected
	**/
	private static function validateEmail($requestName,$xmlSpec){
		$data = JRequest::getVar($requestName);
		if(!JMailHelper::isEmailAddress ($data))		
			return JText:: _ ('INCORRECT_MAIL_FORMAT' );
		return null;	
	}
	/**
	* Validate an captcha field
	* @param $requestName input name
	* @param xmlSpec XML specification of the input based on XmlEngine spec
	* @param $sid the session id associated to the captcha
	* @return error message or null if no error detected
	**/
	private static function validateJQckCaptcha($requestName,$xmlSpec,$sid){
		$data = JRequest::getVar($requestName);
		$captchaService = new JqckCaptchaService();
		$result = $captchaService->checkJqckCaptcha($sid,$data);
		if(!$result)		
			return JText:: _ ('INCORRECT_JQCK_CAPTCHA' );
		return null;	
	}
        /**
         * Check numeric values
         * @return null if ok or error message
         */
	private static function validateNumricField($requestName,$xmlSpec){
            $data = JRequest::getVar($requestName);
            $bool_min = true;
            $bool_max = true;
            if(ctype_digit($data)){                        
                $bool_min = JqckFieldsService::checkMinValueRespected($requestName,$xmlSpec);
                $bool_max = JqckFieldsService::checkMaxValueRespected($requestName,$xmlSpec);
                
                if(!$bool_min && !bool_max){                 
                    return JText::sprintf( 'FIELD_NUMERIC_MIN_MAX', $xmlSpec->label, $xmlSpec->min, $xmlSpec->max );
                }
                if(!$bool_min){
                    return JText::sprintf( 'FIELD_NUMERIC_MIN', $xmlSpec->label, $xmlSpec->min );
                }
                if(!$bool_max){
                    return JText::sprintf( 'FIELD_NUMERIC_MAX', $xmlSpec->label, $xmlSpec->max );
                }
                
            }else{
                JText::sprintf( 'INCORRECT_NUMERIC_FORMAT', $xmlSpec->label);
            }
            
        }
                /**
         * Check if max value is respected
         * @return boolean
         */
        private static function checkMaxValueRespected($requestName,$xmlSpec){
            if($xmlSpec->max != null && $xmlSpec->max != 0 ){               
                 if(JRequest::getVar($requestName)> $xmlSpec->max){
                     return false;
                 }
            } 
            return true;
        }
        /**
         * Check if min value is respected
         * @return boolean
         */
        private static function checkMinValueRespected($requestName,$xmlSpec){
            if($xmlSpec->min != null && $xmlSpec->min != 0 ){               
                 if(JRequest::getVar($requestName)< $xmlSpec->min){
                     return false;
                 }
            } 
            return true;
        }

}